// Copyright (c) 2017 Hardik Bagdi <hbagdi1@binghamton.edu>
//
// MIT License
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
//
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

package unsplash

import (
	"io/ioutil"
	"log"
	"testing"

	"github.com/stretchr/testify/assert"
)

func TestListOpt(T *testing.T) {
	assert := assert.New(T)
	log.SetOutput(ioutil.Discard)

	var opt ListOpt
	assert.Equal(true, opt.Valid())
	assert.Equal(1, opt.Page)
	assert.Equal(10, opt.PerPage)
	assert.Equal(Latest, opt.OrderBy)
	opt = *defaultListOpt
	assert.Equal(true, opt.Valid())

	opt = ListOpt{OrderBy: Popular}
	assert.Equal(true, opt.Valid())
	assert.Equal(1, opt.Page)
	assert.Equal(10, opt.PerPage)

	opt = ListOpt{Page: 10}
	assert.Equal(true, opt.Valid())
	assert.Equal(Latest, opt.OrderBy)
	assert.Equal(10, opt.Page)
	assert.Equal(10, opt.PerPage)

	opt = ListOpt{PerPage: 20, OrderBy: Oldest}
	assert.Equal(true, opt.Valid())
	assert.Equal(Oldest, opt.OrderBy)
	assert.Equal(1, opt.Page)
	assert.Equal(20, opt.PerPage)
	log.Println(opt.String())

	opt.OrderBy = "Duck"
	assert.Equal(false, opt.Valid())
}
